marimo_jupyter_extension: Jupyter extension to proxy marimo with JupyterLab integration
=======================================================================================

Description
-----------

Jupyter extension to proxy marimo with JupyterLab integration

License
-------

Upstream Contact
----------------

https://pypi.org/project/marimo-jupyter-extension/

